@@ -9,7 +9,7 @@
  * This is where the mailboxes are listed. This controls most of what
  * goes on in SquirrelMail.
  *
- * $Id: right_main.php,v 1.71 2002/02/17 18:32:54 teepe Exp $
+ * $Id: right_main.php,v 1.78 2002/04/17 18:52:22 jmunro Exp $
  */
 
 require_once('../src/validate.php');
@@ -36,9 +36,22 @@ require_once('../functions/display_messages.php');
 $bob = getHashedFile($username, $data_dir, "username.pref");
 
 /* Open a connection on the imap port (143) */
+
 $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
-if( isset( $PG_SHOWNUM ) ) {
+global $PG_SHOWNUM;
+if (isset($PG_SHOWALL)) {
+    if ($PG_SHOWALL) {
+       $PG_SHOWNUM=999999;
+       $show_num=$PG_SHOWNUM;
+       session_register('PG_SHOWNUM');
+    }
+    else {
+       session_unregister('PG_SHOWNUM');
+       unset($PG_SHOWNUM);
+    }
+}
+else if( isset( $PG_SHOWNUM ) ) {
     $show_num = $PG_SHOWNUM;
 }
 
@@ -46,13 +59,16 @@ if (isset($newsort) && $newsort != $sort) {
     setPref($data_dir, $username, 'sort', $newsort);
 }
 
+
+
 /* If the page has been loaded without a specific mailbox, */
 /* send them to the inbox                                  */
 if (!isset($mailbox)) {
     $mailbox = 'INBOX';
     $startMessage = 1;
 }
-   
+
+
 if (!isset($startMessage) || ($startMessage == '')) {
     $startMessage = 1;
 }
@@ -63,12 +79,52 @@ if ($imap_server_type == 'uw' && (strstr($mailbox, '../') ||
    $mailbox = 'INBOX';
 }
 
+/* decide if we are thread sorting or not */
+global $allow_thread_sort;
+if ($allow_thread_sort == TRUE) {
+    if (isset($set_thread)) {
+        if ($set_thread == 1) {
+            setPref($data_dir, $username, "thread_$mailbox", 1);
+            $thread_sort_messages = '1';    
+        }
+        elseif ($set_thread == 2)  {
+            setPref($data_dir, $username, "thread_$mailbox", 0);
+            $thread_sort_messages = '0';    
+        }
+    }
+    else {
+        $thread_sort_messages = getPref($data_dir, $username, "thread_$mailbox");
+    }
+}
+else {
+    $thread_sort_messages = 0;
+} 
+
+global $color;
+if( isset($do_hook) && $do_hook ) {
+    do_hook ("generic_header");
+}
+
 sqimap_mailbox_select($imapConnection, $mailbox);
-displayPageHeader($color, $mailbox);
+
+if (isset($composenew)) {
+    $width= getPref($username, $data_dir, 'editor_size', 76);
+    if ($width < 65) {
+        $pix_width = 560;
+    } else {
+        $width = (.9*$width);
+        $pix_width = intval($width).'0';
+    }
+    $features = "toolbar=no, width=$pix_width, height=650, scrollbars=yes, resizable=yes target=_blank";
+    $location = 'compose.php?mailbox='. urlencode($mailbox).'&attachedmessages=true&session='."$session";
+    $onload= "window.open(\"$location\",\"compose_window_$session\", \"$features\");";
+    displayPageHeader($color, $mailbox, $onload);
+} else {
+    displayPageHeader($color, $mailbox);
+}
 echo "<br>\n";
 
 do_hook('right_main_after_header');
-
 if (isset($note)) {
     echo "<CENTER><B>$note</B></CENTER><BR>\n";
 }
@@ -144,7 +200,6 @@ if ($use_mailbox_cache && session_is_registered('msgs')) {
     session_register('numMessages');
     $_SESSION['numMessages'] = $numMessages;
 }
-
 do_hook('right_main_bottom');
 sqimap_logout ($imapConnection);
 
